@@ -1,7 +1,7 @@
-/* 
+/*
  * awesome.h - awesome main header
  *
- * Copyright © 2007 Julien Danjou <julien@danjou.info>
+ * Copyright © 2007-2008 Julien Danjou <julien@danjou.info>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,9 +22,9 @@
 #ifndef AWESOME_AWESOME_H
 #define AWESOME_AWESOME_H
 
-#include "config.h"
+#include "uicb.h"
 
-void uicb_quit(Display *, DC *, awesome_config *, const char *);        /* quit awesome nicely */
-int xerror(Display *, XErrorEvent *);   /* awesome's X error handler */
+Uicb uicb_quit;
 
 #endif
+// vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
