@@ -631,6 +631,8 @@ cfg_opt_t menu_opts[] =
     CFG_INT((char *) "x", 0xffffffff, CFGF_NONE),
     /** Y coordinate, do not set for auto. */
     CFG_INT((char *) "y", 0xffffffff, CFGF_NONE),
+    /** String matching mode (true to complete string) */
+    CFG_BOOL((char *) "match_string", cfg_false, CFGF_NONE),
     /** Styles to use for this menu. */
     CFG_SEC((char *) "styles", styles_opts, CFGF_NONE),
     CFG_AWESOME_END()
