@@ -25,6 +25,7 @@
 #include "tag.h"
 #include "event.h"
 #include "common/util.h"
+#include "common/configopts.h"
 
 extern AwesomeConf globalconf;
 
@@ -58,6 +59,17 @@ isurgent(Tag *t)
     return False;
 }
 
+static style_t
+taglist_style_get(VirtScreen vscreen, Tag *tag)
+{
+    if(tag->selected)
+        return vscreen.styles.focus;
+    else if(isurgent(tag))
+        return vscreen.styles.urgent;
+
+    return vscreen.styles.normal;
+}
+
 static int
 taglist_draw(Widget *widget,
              DrawCtx *ctx,
@@ -68,16 +80,19 @@ taglist_draw(Widget *widget,
     Client *sel = globalconf.focus->client;
     VirtScreen vscreen = globalconf.screens[widget->statusbar->screen];
     int w = 0, flagsize;
-    XColor *colors;
-    Area area;
+    style_t style;
+    area_t area;
 
-    flagsize = (vscreen.font->height + 2) / 3;
+    flagsize = (vscreen.styles.normal.font->height + 2) / 3;
 
     widget->area.width = 0;
 
     for(tag = vscreen.tags; tag; tag = tag->next)
-        widget->area.width += draw_textwidth(ctx->display, vscreen.font, tag->name)
-            + vscreen.font->height;
+    {
+        style = tag->selected ? vscreen.styles.focus : vscreen.styles.normal;
+        widget->area.width += draw_textwidth(ctx->display, style.font, tag->name)
+            + style.font->height;
+    }
 
     if(!widget->user_supplied_x)
         widget->area.x = widget_calculate_offset(widget->statusbar->width,
@@ -91,32 +106,26 @@ taglist_draw(Widget *widget,
     widget->area.width = 0;
     for(tag = vscreen.tags; tag; tag = tag->next)
     {
-        w = draw_textwidth(ctx->display, vscreen.font, tag->name) + vscreen.font->height;
-        if(tag->selected)
-            colors = vscreen.colors_selected;
-        else if(isurgent(tag))
-            colors = vscreen.colors_urgent;
-        else
-            colors = vscreen.colors_normal;
+        style = taglist_style_get(vscreen, tag);
+        w = draw_textwidth(ctx->display, style.font, tag->name) + style.font->height;
         area.x = widget->area.x + widget->area.width;
         area.y = widget->area.y;
         area.width = w;
         area.height = widget->statusbar->height;
         draw_text(ctx, area,
                   AlignCenter,
-                  vscreen.font->height / 2,
-                  vscreen.font,
+                  style.font->height / 2,
                   tag->name,
-                  colors[ColFG],
-                  colors[ColBG]);
+                  style);
+
         if(isoccupied(tag))
         {
-            Area rectangle = { widget->area.x + widget->area.width,
+            area_t rectangle = { widget->area.x + widget->area.width,
                                widget->area.y,
                                flagsize,
                                flagsize,
-                               NULL };
-            draw_rectangle(ctx, rectangle, sel && is_client_tagged(sel, tag), colors[ColFG]);
+                               NULL, NULL };
+            draw_rectangle(ctx, rectangle, 1.0, sel && is_client_tagged(sel, tag), style.fg);
         }
         widget->area.width += w;
     }
@@ -133,6 +142,7 @@ taglist_button_press(Widget *widget, XButtonPressedEvent *ev)
     Tag *tag;
     char buf[4];
     int prev_width = 0, width = 0, i = 1;
+    style_t style;
 
     for(b = widget->buttons; b; b = b->next)
         if(ev->button == b->button && CLEANMASK(ev->state) == b->mod && b->func)
@@ -142,8 +152,9 @@ taglist_button_press(Widget *widget, XButtonPressedEvent *ev)
               case Bottom:
                 for(tag = vscreen.tags; tag; tag = tag->next, i++)
                 {
-                    width = draw_textwidth(globalconf.display, vscreen.font, tag->name)
-                        + vscreen.font->height;
+                    style = taglist_style_get(vscreen, tag);
+                    width = draw_textwidth(globalconf.display, style.font, tag->name)
+                        + style.font->height;
                     if(ev->x >= widget->area.x + prev_width
                        && ev->x < widget->area.x + prev_width + width)
                     {
@@ -157,7 +168,8 @@ taglist_button_press(Widget *widget, XButtonPressedEvent *ev)
               case Right:
                 for(tag = vscreen.tags; tag; tag = tag->next, i++)
                 {
-                    width = draw_textwidth(globalconf.display, vscreen.font, tag->name) + vscreen.font->height;
+                    style = taglist_style_get(vscreen, tag);
+                    width = draw_textwidth(globalconf.display, style.font, tag->name) + style.font->height;
                     if(ev->y >= widget->area.x + prev_width
                        && ev->y < widget->area.x + prev_width + width)
                     {
@@ -171,7 +183,8 @@ taglist_button_press(Widget *widget, XButtonPressedEvent *ev)
               default:
                 for(tag = vscreen.tags; tag; tag = tag->next, i++)
                 {
-                    width = draw_textwidth(globalconf.display, vscreen.font, tag->name) + vscreen.font->height;
+                    style = taglist_style_get(vscreen, tag);
+                    width = draw_textwidth(globalconf.display, style.font, tag->name) + style.font->height;
                     if(widget->statusbar->width - ev->y >= widget->area.x + prev_width
                        && widget->statusbar->width - ev->y < widget->area.x + prev_width + width)
                     {
@@ -193,7 +206,7 @@ taglist_new(Statusbar *statusbar, cfg_t *config)
     widget_common_new(w, statusbar, config);
     w->draw = taglist_draw;
     w->button_press = taglist_button_press;
-    w->alignment = draw_get_align(cfg_getstr(config, "align"));
+    w->alignment = cfg_getalignment(config, "align");
 
     /* Set cache property */
     w->cache.flags = WIDGET_CACHE_TAGS | WIDGET_CACHE_CLIENTS;
