@@ -22,6 +22,7 @@
 #include "widget.h"
 #include "screen.h"
 #include "common/util.h"
+#include "common/configopts.h"
 
 extern AwesomeConf globalconf;
 
@@ -30,8 +31,7 @@ typedef struct
     char *text;
     int width;
     Alignment align;
-    XColor fg;
-    XColor bg;
+    style_t style;
 } Data;
 
 static int
@@ -44,7 +44,7 @@ textbox_draw(Widget *widget, DrawCtx *ctx, int offset, int used)
     else if(widget->alignment == AlignFlex)
         widget->area.width = widget->statusbar->width - used;
     else
-        widget->area.width = MIN(draw_textwidth(ctx->display, widget->font, d->text),
+        widget->area.width = MIN(draw_textwidth(ctx->display, d->style.font, d->text),
                                  widget->statusbar->width - used);
 
     widget->area.height = widget->statusbar->height;
@@ -57,42 +57,52 @@ textbox_draw(Widget *widget, DrawCtx *ctx, int offset, int used)
     if(!widget->user_supplied_y)
         widget->area.y = 0;
 
-    draw_text(ctx, widget->area, d->align, 0, widget->font, d->text, d->fg, d->bg);
+    draw_text(ctx, widget->area, d->align, 0, d->text, d->style);
 
     return widget->area.width;
 }
 
-static void
-textbox_tell(Widget *widget, char *command)
+static widget_tell_status_t
+textbox_tell(Widget *widget, char *property, char *command)
 {
-    char *ntok, *tok;
-    ssize_t command_len = a_strlen(command);
-    int i = 0, phys_screen = get_phys_screen(widget->statusbar->screen);
-
     Data *d = widget->data;
-    if (d->text)
-        p_delete(&d->text);
+    font_t *newfont;
 
-    for (i = 0, tok = command; tok && i < 2 && *tok == '#'; i++)
+    if(!a_strcmp(property, "text"))
     {
-        ntok = strchr(tok, ' ');
-        if((!ntok && command_len - (tok - command) == 7) ||
-           ntok - tok == 7)
+        if (d->text)
+            p_delete(&d->text);
+        d->text = a_strdup(command);
+    }
+    else if(!a_strcmp(property, "fg"))
+        if(draw_color_new(globalconf.display, widget->statusbar->screen, command, &d->style.fg))
+            return WIDGET_NOERROR;
+        else
+            return WIDGET_ERROR_FORMAT_COLOR;
+    else if(!a_strcmp(property, "bg"))
+        if(draw_color_new(globalconf.display, widget->statusbar->screen, command, &d->style.bg))
+            return WIDGET_NOERROR;
+        else
+            return WIDGET_ERROR_FORMAT_COLOR;
+    else if(!a_strcmp(property, "font"))
+    {
+        if((newfont = draw_font_new(globalconf.display, command)))
         {
-            if(ntok)
-                *ntok = 0;
-            if(!i)
-                draw_color_new(globalconf.display, phys_screen, tok, &d->fg);
-            else
-                draw_color_new(globalconf.display, phys_screen, tok, &d->bg);
-            if (ntok)
-                *ntok = ' ';
-            tok = ntok + (ntok != NULL);
+            if(d->style.font != globalconf.screens[widget->statusbar->screen].styles.normal.font)
+                draw_font_delete(&d->style.font);
+            d->style.font = newfont;
         }
         else
-            break;
+            return WIDGET_ERROR_FORMAT_FONT;
     }
-    d->text = a_strdup(tok);
+    else if(!a_strcmp(property, "width"))
+        d->width = atoi(command);
+    else if(!a_strcmp(property, "text_align"))
+        d->align = draw_align_get_from_str(command);
+    else
+        return WIDGET_ERROR;
+
+    return WIDGET_NOERROR;
 }
 
 Widget *
@@ -100,34 +110,22 @@ textbox_new(Statusbar *statusbar, cfg_t *config)
 {
     Widget *w;
     Data *d;
-    char *buf;
 
     w = p_new(Widget, 1);
     widget_common_new(w, statusbar, config);
     w->draw = textbox_draw;
     w->tell = textbox_tell;
-    w->alignment = draw_get_align(cfg_getstr(config, "align"));
+    w->alignment = cfg_getalignment(config, "align");
 
     w->data = d = p_new(Data, 1);
 
-    if((buf = cfg_getstr(config, "fg")))
-        draw_color_new(globalconf.display, get_phys_screen(statusbar->screen), buf, &d->fg);
-    else
-        d->fg = globalconf.screens[statusbar->screen].colors_normal[ColFG];
-
-    if((buf = cfg_getstr(config, "bg")))
-        draw_color_new(globalconf.display, get_phys_screen(statusbar->screen), buf, &d->bg);
-    else
-        d->bg = globalconf.screens[statusbar->screen].colors_normal[ColBG];
+    draw_style_init(globalconf.display, statusbar->phys_screen,
+                    cfg_getsec(config, "style"),
+                    &d->style,
+                    &globalconf.screens[statusbar->screen].styles.normal);
 
     d->width = cfg_getint(config, "width");
-    d->align = draw_get_align(cfg_getstr(config, "text_align"));
-
-    if((buf = cfg_getstr(config, "font")))
-        w->font = XftFontOpenName(globalconf.display, get_phys_screen(statusbar->screen), buf);
-
-    if(!w->font)
-        w->font = globalconf.screens[statusbar->screen].font;
+    d->align = cfg_getalignment(config, "text_align");
 
     d->text = a_strdup(cfg_getstr(config, "text"));
 
